@@ -1,13 +1,13 @@
 
 
 library(vcfR)
-library(testthat)
+#library(testthat)
 context("addID")
 
-data("vcfR_example")
 
 
 test_that("addID works",{
+  data("vcfR_example")
   x <- addID(vcf)
   expect_equal( sum( is.na(x@fix[,'ID']) ), 0 )
 })
